﻿/// @file       wifidemo_csharp_wince6
/// @copyright  Copyright (c) 2014 Toradex AG
/// @author     $ guc $
/// @date       $ 08/05/14 $
/// @brief      This is a demo to demonstrate how to configure wireless network
///             in C#.

using System;
using System.Linq;
using System.Collections.Generic;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Text;
using System.Windows.Forms;
using OpenNETCF.Net;


namespace wifidemo_csharp_wince6
{
    public partial class Form1 : Form
    {
        OpenNETCF.Net.NetworkInformation.WirelessZeroConfigNetworkInterface INw;
        OpenNETCF.Net.NetworkInformation.AccessPointCollection accessPointCollection;

        public Form1()
        {
            InitializeComponent();
        }

        public void user_action(object sender, EventArgs e)    ///< On load
        {
            /// Check available network interfaces
            foreach (OpenNETCF.Net.NetworkInformation.INetworkInterface networkInterface in OpenNETCF.Net.NetworkInformation.WirelessNetworkInterface.GetAllNetworkInterfaces())
            {

                if (networkInterface.Description.Equals("RT28701"))    /// If network interface is RT28701
                {
                    /// Display current configurations
                    textBox1.Text += ("Description: " + networkInterface.Description + "\r\n");
                    textBox1.Text += ("IP: " + networkInterface.CurrentIpAddress + "\r\n");
                    textBox1.Text += ("ID: " + networkInterface.Id + "\r\n");
                    textBox1.Text += ("Status: " + networkInterface.InterfaceOperationalStatus + "\r\n");
                    networkInterface.Bind();

                    try
                    {
                      INw = (OpenNETCF.Net.NetworkInformation.WirelessZeroConfigNetworkInterface)networkInterface;    ///< Obtain wireless zero configuration interface 
                    }
                    catch
                    {
                        textBox1.Text = "Network interface is not Wireless Zero Configuration";     ///< Possible reason can be that image in WinCE 7 
                    }

                    accessPointCollection = INw.NearbyAccessPoints;

                    textBox1.Text += ("Wireless Network available are:\r\n");
                    /// Get available wireless network 
                    foreach (OpenNETCF.Net.NetworkInformation.IAccessPoint iAccessPoint in accessPointCollection)
                    {
                        comboBox1.Items.Add(iAccessPoint.Name);
                        textBox1.Text += (iAccessPoint.Name + " -  signal strength: " + iAccessPoint.SignalStrength + " (" + iAccessPoint.SignalStrength.Decibels + "dB)\r\n");
                    }
 
                  }
               }
        }
        /// If disconnect button is clicked 
        private void disconnectEvent(object sender, EventArgs e)
        {
            bool retValue = false;
            string ssid = comboBox1.SelectedItem.ToString();
            textBox1.Text = "Disconnecting from preferred access point\r\n";

            INw.DhcpRelease();
            INw.RemovePreferredNetwork(ssid);    ///< Remove preferred network
            if (retValue == true)
            {
                textBox1.Text = "Disconnected from preferred access point\r\n";
            }
            comboBox1.Enabled = true;
            txtPassword.Enabled = true;
            txtPassword.Text = "";
        }

        private void exitEvent(object sender, CancelEventArgs e)
        {

        }
        /// If connect button is clicked
        private void ConnectEvent(object sender, EventArgs e)
        {
            bool retVal = false;
            string password = txtPassword.Text.ToString();      ///< Get password
            string ssid = comboBox1.SelectedItem.ToString();    ///< Get SSID selected
            foreach (OpenNETCF.Net.NetworkInformation.IAccessPoint iap in accessPointCollection)
            {
                try
                {
                    if (iap.Name.Equals(ssid))
                    {
                        OpenNETCF.Net.NetworkInformation.EAPParameters eap = null;
                        eap = new OpenNETCF.Net.NetworkInformation.EAPParameters();
                        eap.Enable8021x = true;
                        eap.EapType = OpenNETCF.Net.NetworkInformation.EAPType.Default;
                        eap.EapFlags = OpenNETCF.Net.NetworkInformation.EAPFlags.Enabled;

                        retVal = INw.AddPreferredNetwork(ssid, true, password, 1, iap.AuthenticationMode, accessPointCollection[0].Privacy, eap);
                        if (retVal == true)
                        {
                            INw.ConnectToPreferredNetwork(iap.Name);
                            INw.DhcpRenew();
                            textBox1.Text = ("Connecting to preferred wireless access point\r\n");

                            System.Threading.Thread.Sleep(10000);
                            /// Check if connection is successful
                            if (INw.AssociatedAccessPoint.Equals(ssid))
                            {
                                comboBox1.Enabled = false;
                                txtPassword.Enabled = false;
                                textBox1.Text = ("Connected to preferred wireless access point\r\n");
                            }
                            else
                            {
                                textBox1.Text = ("Could not connect to network, Try entering correct password\r\n");
                            }
                        }
                        else
                        {
                            textBox1.Text = ("Unable to set wireless settings for the access point\r\n");
                        }
                    }
                }
                catch
                {
                    textBox1.Text = "Could not connect to network, Try entering correct password";
                }
            }
        }

    }
}


